@@ -1,6 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
 # Copyright (C) 2010-2021, Roland van Ipenburg
-package WWW::Wookie v1.1.2;
+package WWW::Wookie v1.1.3;
 use strict;
 use warnings;
 
@@ -21,7 +21,7 @@ WWW::Wookie - Apache Wookie Connector Framework implementation
 
 =head1 VERSION
 
-This document describes WWW::Wookie version C<v1.1.2>, which is probably the
+This document describes WWW::Wookie version C<v1.1.3>, which is probably the
 latest version because the Wookie project is retired
 L<http://attic.apache.org/projects/wookie.html>
 
@@ -62,8 +62,6 @@ L<http://wookie.apache.org|http://wookie.apache.org>.
 
 =item * L<LWP::UserAgent|LWP::UserAgent>
 
-=item * L<Log::Log4perl|Log::Log4perl>
-
 =item * L<Moose|Moose>
 
 =item * L<Moose::Role|Moose::Role>
@@ -95,7 +93,7 @@ a port of the reference Java version of the Wookie Connector Framework.
 
 =head1 DIAGNOSTICS
 
-This module uses L<Log::Log4perl|Log::Log4perl> for logging.
+This module uses L<Log::Log4perl|Log::Log4perl> for logging when resurrected.
 
 =head1 BUGS AND LIMITATIONS
 
