@@ -1,19 +1,19 @@
 # -*- cperl; cperl-indent-level: 4 -*-
 # Copyright (C) 2010-2021, Roland van Ipenburg
-package WWW::Wookie::Connector::Service v1.1.2;
+package WWW::Wookie::Connector::Service v1.1.3;
 use strict;
 use warnings;
 
 use utf8;
 use 5.020000;
 
+#use Log::Log4perl qw(:resurrect :easy get_logger);
 use Exception::Class;
 use HTTP::Headers;
 use HTTP::Request;
 use HTTP::Request::Common;
 use HTTP::Status qw(HTTP_CREATED HTTP_OK HTTP_UNAUTHORIZED HTTP_FORBIDDEN);
 use LWP::UserAgent qw/POST/;
-use Log::Log4perl qw(:easy get_logger);
 use Moose qw/around has with/;
 use Regexp::Common qw(URI);
 use URI::Escape qw(uri_escape);
@@ -84,17 +84,15 @@ Readonly::Hash my %ERR => (
 );
 ## use critic
 
-## no critic qw(ProhibitCallsToUnexportedSubs)
-Log::Log4perl::easy_init($ERROR);
-## use critic
+###l4p Log::Log4perl::easy_init($ERROR);
 
-has '_logger' => (
-    'is'      => 'ro',
-    'isa'     => 'Log::Log4perl::Logger',
-    'default' =>
-      sub { Log::Log4perl->get_logger('WWW::Wookie::Connector::Service') },
-    'reader' => 'getLogger',
-);
+###l4p has '_logger' => (
+###l4p     'is'      => 'ro',
+###l4p     'isa'     => 'Log::Log4perl::Logger',
+###l4p     'default' =>
+###l4p       sub { Log::Log4perl->get_logger('WWW::Wookie::Connector::Service') },
+###l4p     'reader' => 'getLogger',
+###l4p );
 
 has '_conn' => (
     'is'     => 'rw',
@@ -131,7 +129,7 @@ sub getAvailableServices {
         'KeyAttr'    => { 'widget' => q{id}, 'service' => q{name} },
     )->XMLin( $response->content );
     while ( my ( $name, $value ) = each %{ ${$xml_obj}{'service'} } ) {
-        $self->getLogger->debug($name);
+        ###l4p $self->getLogger->debug($name);
         my $service = WWW::Wookie::Widget::Category->new( 'name' => $name );
         while ( my ( $id, $value ) = each %{ ${$value}{'widget'} } ) {
             $service->put(
@@ -150,7 +148,7 @@ sub getAvailableWidgets {
     my $url     = $self->_append_path($WIDGETS);
     my $content = {};
     if ( !defined $service || $service eq $ALL ) {
-        $self->getLogger->debug( $LOG{'ALL_TRUE'} );
+        ###l4p $self->getLogger->debug( $LOG{'ALL_TRUE'} );
         ${$content}{'all'} = q{true};
     }
     elsif ($service) {
@@ -264,7 +262,7 @@ sub getOrCreateInstance {
     };
 
     if ( my $e = Exception::Class->caught('WookieConnectorException') ) {
-        $self->getLogger->error( $e->error );
+        ###l4p $self->getLogger->error( $e->error );
         $e->rethrow;
         return $FALSE;
     }
@@ -278,10 +276,10 @@ sub getUsers {
     if ( ref $instance ne q{WWW::Wookie::Widget::Instance} ) {
         $instance = $self->getOrCreateInstance($instance);
     }
-    $self->getLogger->debug( sprintf $LOG{'GET_USERS'},
-        $instance->getIdentifier );
+    ###l4p $self->getLogger->debug( sprintf $LOG{'GET_USERS'},
+    ###l4p     $instance->getIdentifier );
     my $url = $self->_append_path($PARTICIPANTS);
-    $self->getLogger->debug( sprintf $LOG{'USING_URL'}, $url );
+    ###l4p $self->getLogger->debug( sprintf $LOG{'USING_URL'}, $url );
 
     __check_url( $url, $ERR{'MALFORMED_URL'} );
     my $response =
@@ -387,12 +385,12 @@ sub setProperty {
         }
     };
     if ( my $e = Exception::Class->caught('WookieConnectorException') ) {
-        $self->getLogger->error( $e->error );
+        ###l4p $self->getLogger->error( $e->error );
         $e->rethrow;
         return $FALSE;
     }
     if ( my $e = Exception::Class->caught('WookieWidgetInstanceException') ) {
-        $self->getLogger->error( $e->error );
+        ###l4p $self->getLogger->error( $e->error );
         $e->rethrow;
         return $FALSE;
     }
@@ -594,13 +592,13 @@ sub _do_request {
     {
         $url .= $QUERY . $content;
     }
-    $self->getLogger->debug( sprintf $LOG{'DO_REQUEST'}, $method, $url );
+    ###l4p $self->getLogger->debug( sprintf $LOG{'DO_REQUEST'}, $method, $url );
     my $request = HTTP::Request->new(
         $method => $url,
         HTTP::Headers->new(),
     );
     my $response = $self->_ua->request($request);
-    $self->getLogger->debug( sprintf $LOG{'RESPONSE_CODE'}, $response->code );
+    ###l4p $self->getLogger->debug( sprintf $LOG{'RESPONSE_CODE'}, $response->code );
     if (   $response->code == HTTP_UNAUTHORIZED
         || $response->code == HTTP_FORBIDDEN )
     {
@@ -668,7 +666,7 @@ data requests and responses
 
 =head1 VERSION
 
-This document describes WWW::Wookie::Connector::Service version C<v1.1.2>
+This document describes WWW::Wookie::Connector::Service version C<v1.1.3>
 
 =head1 SYNOPSIS
 
