@@ -1,14 +1,12 @@
 # -*- cperl; cperl-indent-level: 4 -*-
 # Copyright (C) 2010-2021, Roland van Ipenburg
-package WWW::Wookie::Connector::Service::Interface;
+package WWW::Wookie::Connector::Service::Interface v1.1.3;
 use strict;
 use warnings;
 
 use utf8;
 use 5.020000;
 
-our $VERSION = 'v1.1.2';
-
 use Moose::Role qw/requires/;
 requires 'getAvailableServices';
 requires 'getAvailableWidgets';
@@ -43,7 +41,7 @@ L<WWW::Wookie::Connector::Service|WWW::Wookie::Connector::Service>
 =head1 VERSION
 
 This document describes WWW::Wookie::Connector::Service::Interface version
-C<v1.1.2>
+C<v1.1.3>
 
 =head1 SYNOPSIS
 
